## 债券大宗交易

接口：bond_blk

权限：用户满5000积分有数据权限，单次最大1000条，可根据日期循环提取，总量不限制

描述：获取沪深交易所债券大宗交易数据，可以通过数据工具调试和查看数据。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 债券代码 |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | 债券代码 |
| name | str | Y | 债券名称 |
| price | float | Y | 成交价（元） |
| vol | float | Y | 累计成交数量（万股/万份/万张/万手） |
| amount | float | Y | 累计成交金额（万元） |

接口示例

```python
pro = ts.pro_api()

df = pro.bond_blk(start_date='20210701', end_date='20210930')
```

数据样例

```python
trade_date    ts_code    name     price    vol    amount
0     20210930  152497.SH   20黔西南   75.00  35.00  2625.00
```